@@ -24,13 +24,13 @@ function(x, max.print=10, ...)
     max.print <- nrow(x$odds)
 
   cat("\nFormula:\n")
-  print.formula(x$formula)
+  print(x$formula)
   cat("\nHeuristic:\n")
   cat(x$heuristic)
   cat("\n")
 
   cat("\nOdds:\n")
-  print.data.frame(as.data.frame(x$odds)[1:min(nrow(x$odds),max.print),], digits=digits)
+  print(as.data.frame(x$odds)[1:min(nrow(x$odds),max.print),], digits=digits)
   if(nrow(x$odds)>max.print)
     cat(paste("... [ omitted ",nrow(x$odds)-max.print," rows ] ...\n",sep=""))
   cat("\n")
